@@ -45,7 +45,6 @@ OC.L10N.register(
     "Writing mode" : "מצב כתיבה",
     "Preferred writing mode for new messages and replies." : "מצב כתיבה מועדף להודעות חדשות ולתגובות.",
     "Default folders" : "תיקיות בררת מחדל",
-    "The folders to use for drafts, sent messages and deleted messages." : "התיקיות משמשות לטיוטות, הודעות שנשלחו והודעות שנמחקו.",
     "Trusted senders" : "שולחים מהימנים",
     "Mail server" : "שרת דוא״ל",
     "Email address" : "כתובת דוא״ל",
@@ -105,8 +104,8 @@ OC.L10N.register(
     "Edit tags" : "עריכת תגיות",
     "Move" : "העברה",
     "Move thread" : "העברת שרשור",
-    "More actions" : "פעולות נוספות",
     "Delete thread" : "מחיקת שרשור",
+    "More actions" : "פעולות נוספות",
     "Edit as new message" : "עריכה כהודעה חדשה",
     "Create event" : "יצירת אירוע",
     "Blind copy recipients only" : "נמענים נסתרים בלבד",
@@ -173,6 +172,11 @@ OC.L10N.register(
     "Delete" : "מחיקה",
     "Copy to clipboard" : "העתקה ללוח הגזירים",
     "Add" : "הוספה",
+    "Tags" : "תגיות",
+    "Select tags" : "בחירת תגיות",
+    "Clear" : "פינוי",
+    "Search" : "חיפוש",
+    "Date" : "תאריך",
     "Disabled" : "מושבת",
     "Enabled" : "מופעל",
     "IMAP Credentials" : "פרטי גישה ל־IMAP",
@@ -227,7 +231,6 @@ OC.L10N.register(
     "Older message" : "הודעה ישנה יותר",
     "Toggle star" : "החלפת מצב כוכב",
     "Toggle unread" : "החלפת מצב קריאה",
-    "Search" : "חיפוש",
     "Refresh" : "רענון",
     "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
     "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
