@@ -1,16 +1,17 @@
 OC.L10N.register(
     "mail",
     {
-    "Auto detect failed. Please use manual mode." : "Automātiski noteikt neizdevās. Lūdzu, izmantojiet manuālo režīmu.",
-    "Updating account failed: " : "Neizdevās labot konts",
-    "Creating account failed: " : "Konta izveide neizdevās:",
     "Embedded message %s" : "Iegultais ziņojums%s",
+    "Important" : "Svarīgi",
+    "Work" : "Darbs",
+    "Personal" : "Personīgs",
+    "Later" : "Vēlāk",
     "Mails" : "E-pasta sūtījumi",
     "Mail" : "E-pasts",
     "💌 A mail app for Nextcloud" : "Nextcloud E-pasta lietotne",
     "Auto" : "Automātiski",
     "Name" : "Nosaukums",
-    "Mail Address" : "E-pasta adrese",
+    "Mail address" : "E-pasta adrese",
     "Password" : "Parole",
     "Manual" : "Manuāli",
     "IMAP Settings" : "IMAP iestatījumi",
@@ -28,28 +29,39 @@ OC.L10N.register(
     "SMTP Port" : "SMTP Port",
     "SMTP User" : "SMTP lietotājs",
     "SMTP Password" : "SMTP parole",
+    "Connecting" : "Savienojuma izveide",
     "Save" : "Saglabāt",
     "Connect" : "Savienoties",
     "Signature" : "Paraksts",
+    "Cancel" : "Atcelt",
     "Add mail account" : "Pievienot e-pasta kontu",
     "Select account" : "Izvēlieties kontu",
     "Subject" : "Temats",
+    "Write message …" : "Rakstiet ziņu...",
     "Add attachment from Files" : "Pievienot pielikumu no failiem",
+    "Enter a date" : "Ievadiet datumu",
     "Sending …" : "Sūta …",
     "Go back" : "Atpakaļ",
     "Retry" : "Mēģināt vēlreiz",
     "Message sent!" : "Vēstule aizsūtīta!",
     "Send" : "Sūtīt",
     "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
+    "Favorite" : "Favorīts",
+    "Read" : "Lasīt",
     "Unselect" : "Noņemt atlasi",
     "Select" : "Atzīmēt",
+    "Edit tags" : "Rediģēt atzīmes",
+    "Move" : "Pārvietot",
+    "Forward" : "Turpināt",
+    "All day" : "Visas dienas",
+    "Create" : "Izveidot",
+    "Comment" : "Komentārs",
+    "Accept" : "Pieņemt",
+    "Decline" : "Noraidīt",
     "Choose" : "Izvēlies",
-    "Favorites" : "Favorīti",
     "Other" : "Cits",
     "Reply" : "Atbildēt",
-    "Forward" : "Turpināt",
     "View source" : "Skatīt avotu",
-    "Attachments" : "Pielikumi",
     "Import into calendar" : "Importēt kalendārā",
     "Download attachment" : "Lejupielādēt pielikumu",
     "Save to Files" : "Saglabāt uz Datnes",
@@ -57,26 +69,37 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
     "Save all to Files" : "Saglabāt visu uz Datnes",
     "The images have been blocked to protect your privacy." : "Attēli tiek bloķēti, lai aizsargātu jūsu konfidencialitāti.",
-    "Move" : "Pārvietot",
-    "New message" : "Jauna ziņa",
-    "Settings" : "Iestatījumi",
     "Quota" : "Kvota",
     "Saving" : "Saglabā",
     "Remove account" : "Noņemt kontu",
-    "Cancel" : "Atcelt",
+    "New message" : "Jauna ziņa",
+    "Message" : "Ziņojums",
     "Delete" : "Dzēst",
+    "Copy to clipboard" : "Kopēt starpliktuvē",
+    "Add" : "Pievienot",
+    "Tags" : "Birkas",
+    "Select tags" : "Izvēlies birkas",
+    "Search" : "Meklēt",
+    "Date" : "Datums",
+    "Disabled" : "Atspējots",
+    "Enabled" : "Iespējots",
+    "Custom" : "Pielāgots",
+    "Unset" : "Neuzstādīts",
+    "Tag already exists" : "Birka jau pastāv",
+    "Remove" : "Noņemt",
+    "Reset" : "Atiestatīt",
     "General" : "Vispārīgs",
     "User" : "Lietotājs",
     "Host" : "Resursdators",
     "Port" : "Ports",
     "Keyboard shortcut" : "Tastatūras saīsne",
     "Keyboard shortcuts" : "Tastatūras saīsnes",
-    "Search" : "Meklēt",
     "Refresh" : "Atsvaidzināt",
     "Connect your mail account" : "Pievienojiet savu e-pasta kontu",
     "All" : "Visi",
     "Archive" : "Arhīvi",
     "Drafts" : "Melnraksti",
+    "Favorites" : "Favorīti",
     "All inboxes" : "Visas iesūtnes",
     "Inbox" : "Iesūtne",
     "Junk" : "Nevēlams",
@@ -90,7 +113,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ja nevēlaties apmeklēt šo lapu, varat atgriezties pie <a href=\"%s\">e-pasta</a>.",
     "Continue to %s" : "Turpināt %s"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
