@@ -58,6 +58,10 @@ OC.L10N.register(
     "Delete" : "Suprimir",
     "Copy to clipboard" : "Copiar dins lo quichapapièrs",
     "Add" : "Apondre",
+    "Tags" : "Etiquetas",
+    "Clear" : "Escafar",
+    "Search" : "Recercar",
+    "Date" : "Data",
     "Disabled" : "Desactivat",
     "Enabled" : "Activada",
     "Custom" : "Personalizats",
@@ -73,7 +77,6 @@ OC.L10N.register(
     "Port" : "Pòrt",
     "Keyboard shortcut" : "Acorchis de clavièr",
     "Keyboard shortcuts" : "Acorchis de clavièr",
-    "Search" : "Recercar",
     "Refresh" : "Refrescar",
     "All" : "Tot",
     "Archive" : "Archius",
