@@ -45,7 +45,6 @@ OC.L10N.register(
     "Writing mode" : "编写模式",
     "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
     "Default folders" : "默认文件夹",
-    "The folders to use for drafts, sent messages and deleted messages." : "用于草稿邮件、已发送邮件和已删除邮件的文件夹。",
     "Sieve filter rules" : "Sieve 过滤器规则",
     "Trusted senders" : "信任的发件人",
     "Mail server" : "邮件服务器",
@@ -120,8 +119,8 @@ OC.L10N.register(
     "Edit tags" : "编辑标签",
     "Move" : "移动",
     "Move thread" : "移动线程",
-    "More actions" : "更多操作 ",
     "Delete thread" : "删除线程",
+    "More actions" : "更多操作 ",
     "Edit as new message" : "编辑为新消息",
     "Create event" : "创建事件",
     "Blind copy recipients only" : "仅向收件人发送无信头副本",
@@ -229,6 +228,11 @@ OC.L10N.register(
     "Copy to clipboard" : "复制到剪贴板",
     "Contact name …" : "联系人姓名 …",
     "Add" : "新增",
+    "Tags" : "标签",
+    "Select tags" : "选择标签",
+    "Clear" : "清空",
+    "Search" : "搜索",
+    "Date" : "日期",
     "Disabled" : "已禁用",
     "Enabled" : "已启用",
     "Sieve Host" : "Sieve 主机",
@@ -344,7 +348,6 @@ OC.L10N.register(
     "Older message" : "更早的信息",
     "Toggle star" : "切换星标",
     "Toggle unread" : "切换未读",
-    "Search" : "搜索",
     "Refresh" : "刷新",
     "Connect your mail account" : "连接您的邮件账号",
     "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
